package com.fastbee.data.controller.userRecharge;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fastbee.common.annotation.Log;
import com.fastbee.common.core.controller.BaseController;
import com.fastbee.common.core.domain.AjaxResult;
import com.fastbee.common.enums.BusinessType;
import com.fastbee.rechargecard.domain.NgRechargeMachines;
import com.fastbee.rechargecard.service.INgRechargeMachinesService;
import com.fastbee.common.utils.poi.ExcelUtil;
import com.fastbee.common.core.page.TableDataInfo;

/**
 * 充值机信息Controller
 *
 * @author kerwincui
 * @date 2024-12-19
 */
@RestController
@RequestMapping("/rechargecard/machines")
@Api(tags = "充值机信息")
public class NgRechargeMachinesController extends BaseController
{
    @Autowired
    private INgRechargeMachinesService ngRechargeMachinesService;

    /**
     * 查询充值机信息列表
     */
//    @PreAuthorize("@ss.hasPermi('rechargecard:machines:list')")
    @GetMapping("/list")
    @ApiOperation("查询充值机信息列表")
    public TableDataInfo list(NgRechargeMachines ngRechargeMachines)
    {
        startPage();
        List<NgRechargeMachines> list = ngRechargeMachinesService.selectNgRechargeMachinesList(ngRechargeMachines);
        return getDataTable(list);
    }

    /**
     * 导出充值机信息列表
     */
    @ApiOperation("导出充值机信息列表")
//    @PreAuthorize("@ss.hasPermi('rechargecard:machines:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, NgRechargeMachines ngRechargeMachines)
    {
        List<NgRechargeMachines> list = ngRechargeMachinesService.selectNgRechargeMachinesList(ngRechargeMachines);
        ExcelUtil<NgRechargeMachines> util = new ExcelUtil<NgRechargeMachines>(NgRechargeMachines.class);
        util.exportExcel(response, list, "充值机信息数据");
    }

    /**
     * 获取充值机信息详细信息
     */
//    @PreAuthorize("@ss.hasPermi('rechargecard:machines:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取充值机信息详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(ngRechargeMachinesService.selectNgRechargeMachinesById(id));
    }

    /**
     * 新增充值机信息
     */
//    @PreAuthorize("@ss.hasPermi('rechargecard:machines:add')")
    @PostMapping
    @ApiOperation("新增充值机信息")
    public AjaxResult add(@RequestBody NgRechargeMachines ngRechargeMachines)
    {
        return toAjax(ngRechargeMachinesService.insertNgRechargeMachines(ngRechargeMachines));
    }

    /**
     * 修改充值机信息
     */
//    @PreAuthorize("@ss.hasPermi('rechargecard:machines:edit')")
    @PutMapping
    @ApiOperation("修改充值机信息")
    public AjaxResult edit(@RequestBody NgRechargeMachines ngRechargeMachines)
    {
        return toAjax(ngRechargeMachinesService.updateNgRechargeMachines(ngRechargeMachines));
    }

    /**
     * 删除充值机信息
     */
//    @PreAuthorize("@ss.hasPermi('rechargecard:machines:remove')")
    @DeleteMapping("/{ids}")
    @ApiOperation("删除充值机信息")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(ngRechargeMachinesService.deleteNgRechargeMachinesByIds(ids));
    }
}
